==> cscec5b-storecloud-impl-3.0.1-20220825.070128-101-sources.jar: com/ejianc/business/storecloud/vo/PickingsVO.java <==
package com.ejianc.business.storecloud.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 现场领料明细
 *
 * @author generator
 *
 */
public class PickingsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String projectName; // 项目名称
    private String billCode; // 单据编号
    private String storeName; // 仓库名称
    private Integer coseFlag; // 3-领料出库4-直接出库
    private String orgName; // 组织名称
    private String pickingName; // 分包领料人
    private String deliveryDate; // 领料日期
    private Date pickingDate;// 领料日期
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private String materialUnitName; // 计量单位
    private BigDecimal outNumber; // 申请数量
    private BigDecimal deliveryNumber; // 出库数量
    private BigDecimal inventoryPrice; // 库存均价
    private BigDecimal surplusTaxMny; // 库存金额含税
    private String deliveryName; // 出库人
    private Long parentOrgId;

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public Integer getCoseFlag() {
        return coseFlag;
    }

    public void setCoseFlag(Integer coseFlag) {
        this.coseFlag = coseFlag;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getPickingName() {
        return pickingName;
    }

    public void setPickingName(String pickingName) {
        this.pickingName = pickingName;
    }

    public String getDeliveryDate() {
        return deliveryDate;
    }

    public void setDeliveryDate(String deliveryDate) {
        this.deliveryDate = deliveryDate;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }

    public BigDecimal getOutNumber() {
        return outNumber;
    }

    public void setOutNumber(BigDecimal outNumber) {
        this.outNumber = outNumber;
    }

    public BigDecimal getDeliveryNumber() {
        return deliveryNumber;
    }

    public void setDeliveryNumber(BigDecimal deliveryNumber) {
        this.deliveryNumber = deliveryNumber;
    }

    public BigDecimal getInventoryPrice() {
        return inventoryPrice;
    }

    public void setInventoryPrice(BigDecimal inventoryPrice) {
        this.inventoryPrice = inventoryPrice;
    }

    public BigDecimal getSurplusTaxMny() {
        return surplusTaxMny;
    }

    public void setSurplusTaxMny(BigDecimal surplusTaxMny) {
        this.surplusTaxMny = surplusTaxMny;
    }

    public String getDeliveryName() {
        return deliveryName;
    }

    public void setDeliveryName(String deliveryName) {
        this.deliveryName = deliveryName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public Date getPickingDate() {
        return pickingDate;
    }

    public void setPickingDate(Date pickingDate) {
        this.pickingDate = pickingDate;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
}

==> cscec5b-storecloud-impl-3.0.1-20220901.105021-149-sources.jar: com/ejianc/business/storecloud/vo/PickingsVO.java <==
package com.ejianc.business.storecloud.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 现场领料明细
 *
 * @author generator
 *
 */
public class PickingsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String projectName; // 项目名称
    private String billCode; // 单据编号
    private String storeName; // 仓库名称
    private Integer coseFlag; // 3-领料出库4-直接出库
    private String orgName; // 组织名称
    private String pickingName; // 分包领料人
    private String deliveryDate; // 领料日期
    private Date pickingDate;// 领料日期
    private String materialName; // 物资名称
    private String materialSpec; // 规格型号
    private String materialUnitName; // 计量单位
    private BigDecimal outNumber; // 申请数量
    private BigDecimal deliveryNumber; // 出库数量
    private BigDecimal inventoryPrice; // 库存均价
    private BigDecimal surplusTaxMny; // 库存金额含税
    private String deliveryName; // 出库人
    private Long parentOrgId;
    private String coseFlags; // 3-领料出库4-直接出库

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public Integer getCoseFlag() {
        return coseFlag;
    }

    public void setCoseFlag(Integer coseFlag) {
        this.coseFlag = coseFlag;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getPickingName() {
        return pickingName;
    }

    public void setPickingName(String pickingName) {
        this.pickingName = pickingName;
    }

    public String getDeliveryDate() {
        return deliveryDate;
    }

    public void setDeliveryDate(String deliveryDate) {
        this.deliveryDate = deliveryDate;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }

    public BigDecimal getOutNumber() {
        return outNumber;
    }

    public void setOutNumber(BigDecimal outNumber) {
        this.outNumber = outNumber;
    }

    public BigDecimal getDeliveryNumber() {
        return deliveryNumber;
    }

    public void setDeliveryNumber(BigDecimal deliveryNumber) {
        this.deliveryNumber = deliveryNumber;
    }

    public BigDecimal getInventoryPrice() {
        return inventoryPrice;
    }

    public void setInventoryPrice(BigDecimal inventoryPrice) {
        this.inventoryPrice = inventoryPrice;
    }

    public BigDecimal getSurplusTaxMny() {
        return surplusTaxMny;
    }

    public void setSurplusTaxMny(BigDecimal surplusTaxMny) {
        this.surplusTaxMny = surplusTaxMny;
    }

    public String getDeliveryName() {
        return deliveryName;
    }

    public void setDeliveryName(String deliveryName) {
        this.deliveryName = deliveryName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public Date getPickingDate() {
        return pickingDate;
    }

    public void setPickingDate(Date pickingDate) {
        this.pickingDate = pickingDate;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getCoseFlags() {
        return coseFlags;
    }

    public void setCoseFlags(String coseFlags) {
        this.coseFlags = coseFlags;
    }
}
